If you would like to contribute to the development of OpenStack, you must
follow the steps in this page:

   https://docs.openstack.org/infra/manual/developers.html

If you already have a good understanding of how the system works and your
OpenStack accounts are set up, you can skip to the development workflow
section of this documentation to learn how changes to OpenStack should be
submitted for review via the Gerrit tool:

   https://docs.openstack.org/infra/manual/developers.html#development-workflow

Pull requests submitted through GitHub will be ignored.

How to file a bug
~~~~~~~~~~~~~~~~~

* Go to
  `Qinling project storyboard <https://storyboard.openstack.org/#!/project/927>`_,
  click ``Add story``.
* Input the bug title and description, be aware the Markdown formatting is
  supported, it's useful if you want to paste code or log. After completion,
  click ``Save Changes``.
* In the created story page, add a tag named 'bug' in the ``Tags`` section.
* Now, you can see the new bug in
  `Qinling project dashboard <https://storyboard.openstack.org/#!/board/79>`_.

How to propose a feature
~~~~~~~~~~~~~~~~~~~~~~~~

* Go to
  `Qinling project storyboard <https://storyboard.openstack.org/#!/project/927>`_,
  click ``Add story``.
* Input the feature title and description, be aware the Markdown formatting is
  supported, it's useful if you want to paste code or log. After completion,
  click ``Save Changes``.
* In the created story page, add a tag named 'feature' in the ``Tags`` section.
* You can optionally break the story into different tasks so that the whole
  story can be tracked properly in different patches.
* Now, you can see the new feature in
  `Qinling project dashboard <https://storyboard.openstack.org/#!/board/79>`_.
